@@ -5,9 +5,10 @@ def array_to_list(input_array, size):
     return [input_array[i] for i in range(size)]
 
 
-def list_to_array(floats, type):
+def list_to_array(py_list, type_in_c):
     """ convert Python list to ctypes array """
-    if floats is None:
-        return None
-    data_length_type = type * len(floats)
-    return ctypes.cast(data_length_type(*floats), ctypes.POINTER(type))
+
+    a = (type_in_c * len(py_list))()
+    a[:] = py_list
+
+    return a
