@@ -1,12 +1,14 @@
 import ctypes
-from ..c_wrapper.run_solo import run_solo_function
+import pyart
+import numpy as np
 
+from ..c_wrapper.run_solo import run_solo_function
 from ..c_wrapper import  DataPair, masked_op
 from ..c_wrapper.function_alias import aliases
 
 se_funfold = aliases['funfold']
 
-def forced_unfolding(input_list_data, bad, nyquist_velocity, dds_radd_eff_unamb_vel, center, dgi_clip_gate=None, boundary_mask=None):
+def forced_unfolding_ray(input_list_data, bad, nyquist_velocity, dds_radd_eff_unamb_vel, center, dgi_clip_gate=None, boundary_mask=None):
     """ 
        Forces all data points to fall within plus or minus the Nyquist
         
@@ -29,7 +31,7 @@ def forced_unfolding(input_list_data, bad, nyquist_velocity, dds_radd_eff_unamb_
 
     args = {
         "data" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), input_list_data),
-        "newData" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), None),
+        "newData" : DataPair.DataTypeValue(np.ctypeslib.ndpointer(ctypes.c_float, flags="C_CONTIGUOUS"), None),
         "nGates" : DataPair.DataTypeValue(ctypes.c_size_t, None),
         "nyquist_velocity" : DataPair.DataTypeValue(ctypes.c_float, nyquist_velocity),
         "dds_radd_eff_unamb_vel" : DataPair.DataTypeValue(ctypes.c_float, dds_radd_eff_unamb_vel),
@@ -42,7 +44,7 @@ def forced_unfolding(input_list_data, bad, nyquist_velocity, dds_radd_eff_unamb_
     return run_solo_function(se_funfold, args)
 
 
-def forced_unfolding_masked(masked_array, nyquist_velocity, dds_radd_eff_unamb_vel, center, boundary_masks=None):
+def forced_unfolding_masked(masked_array, nyquist_velocity: float, dds_radd_eff_unamb_vel: float, center: float, boundary_masks=None):
     """ 
        Forces all data points to fall within plus or minus the Nyquist
         
@@ -60,4 +62,11 @@ def forced_unfolding_masked(masked_array, nyquist_velocity, dds_radd_eff_unamb_v
             AttributeError: if masked_array arg is not a numpy masked array.
     """
 
-    return masked_op.masked_func(forced_unfolding, masked_array, nyquist_velocity, dds_radd_eff_unamb_vel, center, boundary_masks = boundary_masks)
+    return masked_op.masked_func(forced_unfolding_ray, masked_array, nyquist_velocity, dds_radd_eff_unamb_vel, center, boundary_masks = boundary_masks)
+
+
+def forced_unfolding_field(radar: pyart.core.Radar, field: str, new_field: str, dds_radd_eff_unamb_vel: float, center: float, boundary_masks=None, sweep=0):
+
+    with masked_op.SweepManager(radar, sweep, field, new_field) as sm:
+        nyquist_velocity = sm.radar.get_nyquist_vel(sweep)
+        sm.new_masked_array = forced_unfolding_masked(sm.radar_sweep_data, nyquist_velocity, dds_radd_eff_unamb_vel, center, boundary_masks)
