@@ -1,6 +1,6 @@
 import ctypes
-
-from pathlib import Path
+import numpy as np
+import pyart
 
 from ..c_wrapper.run_solo import run_solo_function
 
@@ -9,7 +9,7 @@ from ..c_wrapper.function_alias import aliases
 
 se_radial_shear = aliases['radial_shear']
 
-def radial_shear(input_list_data, bad, seds_gate_diff_interval, dgi_clip_gate=None, boundary_mask=None):
+def radial_shear_ray(input_list_data, bad, seds_gate_diff_interval, dgi_clip_gate=None, boundary_mask=None):
     """ 
         Performs a radial shear, input_list_data is subtracted by an offset of itself
         
@@ -30,7 +30,7 @@ def radial_shear(input_list_data, bad, seds_gate_diff_interval, dgi_clip_gate=No
     args = {
         "seds_gate_diff_interval" : DataPair.DataTypeValue(ctypes.c_size_t, seds_gate_diff_interval),
         "data" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), input_list_data),
-        "newData" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), None),
+        "newData" : DataPair.DataTypeValue(np.ctypeslib.ndpointer(ctypes.c_float, flags="C_CONTIGUOUS"), None),
         "nGates" : DataPair.DataTypeValue(ctypes.c_size_t, None),
         "bad" : DataPair.DataTypeValue(ctypes.c_float, bad),
         "dgi_clip_gate" : DataPair.DataTypeValue(ctypes.c_size_t, dgi_clip_gate),
@@ -40,7 +40,7 @@ def radial_shear(input_list_data, bad, seds_gate_diff_interval, dgi_clip_gate=No
     return run_solo_function(se_radial_shear, args)
 
 
-def radial_shear_masked(masked_array, seds_gate_diff_interval, boundary_masks=None):
+def radial_shear_masked(masked_array, seds_gate_diff_interval: int, boundary_masks=None):
     """ 
         Performs a radial shear, masked_array is subtracted by an offset of itself
         
@@ -57,5 +57,10 @@ def radial_shear_masked(masked_array, seds_gate_diff_interval, boundary_masks=No
             AttributeError: if masked_array arg is not a numpy masked array.
     """
 
+    return masked_op.masked_func(radial_shear_ray, masked_array, seds_gate_diff_interval, boundary_masks = boundary_masks)
 
-    return masked_op.masked_func(radial_shear, masked_array, seds_gate_diff_interval, boundary_masks = boundary_masks)
+
+def radial_shear_field(radar: pyart.core.Radar, field: str, new_field: str, seds_gate_diff_interval: int, boundary_masks=None, sweep=0):
+
+    with masked_op.SweepManager(radar, sweep, field, new_field) as sm:
+        sm.new_masked_array = radial_shear_masked(sm.radar_sweep_data, seds_gate_diff_interval, boundary_masks)
