@@ -1,5 +1,7 @@
 import ctypes
 
+import numpy as np
+
 from ..c_wrapper.run_solo import run_solo_function
 
 from ..c_wrapper import DataPair, masked_op
@@ -9,7 +11,7 @@ se_remove_ac_motion = aliases['remove_ac_motion']
 
 
 
-def remove_ac_motion(input_list_data, bad, vert_velocity, ew_velocity, ns_velocity, ew_gndspd_corr, tilt, elevation, dds_radd_eff_unamb_vel, seds_nyquist_velocity, dgi_clip_gate=None, boundary_mask=None):
+def remove_ac_motion_ray(input_list_data, bad, vert_velocity, ew_velocity, ns_velocity, ew_gndspd_corr, tilt, elevation, dds_radd_eff_unamb_vel, seds_nyquist_velocity, dgi_clip_gate=None, boundary_mask=None):
     """ 
         Performs a <TODO> operation on a list of data.
         
@@ -42,7 +44,7 @@ def remove_ac_motion(input_list_data, bad, vert_velocity, ew_velocity, ns_veloci
         "tilt" : DataPair.DataTypeValue(ctypes.c_float, tilt),
         "elevation" : DataPair.DataTypeValue(ctypes.c_float, elevation),
         "data" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), input_list_data),
-        "newData" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), None),
+        "newData" : DataPair.DataTypeValue(np.ctypeslib.ndpointer(ctypes.c_float, flags="C_CONTIGUOUS"), None),
         "nGates" : DataPair.DataTypeValue(ctypes.c_size_t, None),
         "bad" : DataPair.DataTypeValue(ctypes.c_float, bad),
         "dgi_clip_gate" : DataPair.DataTypeValue(ctypes.c_size_t, dgi_clip_gate),
@@ -78,4 +80,4 @@ def remove_ac_motion_masked(masked_array, vert_velocity, ew_velocity, ns_velocit
     """
 
 
-    return masked_op.masked_func(remove_ac_motion, masked_array, vert_velocity, ew_velocity, ns_velocity, ew_gndspd_corr, tilt, elevation, dds_radd_eff_unamb_vel, seds_nyquist_velocity, boundary_masks = boundary_masks)
+    return masked_op.masked_func(remove_ac_motion_ray, masked_array, vert_velocity, ew_velocity, ns_velocity, ew_gndspd_corr, tilt, elevation, dds_radd_eff_unamb_vel, seds_nyquist_velocity, boundary_masks = boundary_masks)
