@@ -1,5 +1,5 @@
 import ctypes
-
+import numpy as np
 from ..c_wrapper.run_solo import run_solo_function
 
 from ..c_wrapper import DataPair, masked_op
@@ -7,7 +7,7 @@ from ..c_wrapper.function_alias import aliases
 
 se_remove_storm_motion = aliases['remove_storm_motion']
 
-def remove_storm_motion(input_list_data, bad, wind, speed, dgi_dd_rotation_angle, dgi_dd_elevation_angle, dgi_clip_gate=None, boundary_mask=None):
+def remove_storm_motion_ray(input_list_data, bad, wind, speed, dgi_dd_rotation_angle, dgi_dd_elevation_angle, dgi_clip_gate=None, boundary_mask=None):
     """ 
         Performs a <TODO> operation on a list of data.
         
@@ -34,7 +34,7 @@ def remove_storm_motion(input_list_data, bad, wind, speed, dgi_dd_rotation_angle
         "dgi_dd_rotation_angle" : DataPair.DataTypeValue(ctypes.c_float, dgi_dd_rotation_angle),
         "dgi_dd_elevation_angle" : DataPair.DataTypeValue(ctypes.c_float, dgi_dd_elevation_angle),
         "data" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), input_list_data),
-        "newData" : DataPair.DataTypeValue(ctypes.POINTER(ctypes.c_float), None),
+        "newData" : DataPair.DataTypeValue(np.ctypeslib.ndpointer(ctypes.c_float, flags="C_CONTIGUOUS"), None),
         "nGates" : DataPair.DataTypeValue(ctypes.c_size_t, None),
         "bad" : DataPair.DataTypeValue(ctypes.c_float, bad),
         "dgi_clip_gate" : DataPair.DataTypeValue(ctypes.c_size_t, dgi_clip_gate),
@@ -64,4 +64,4 @@ def remove_storm_motion_masked(masked_array, wind, speed, dgi_dd_rotation_angle,
     """
 
 
-    return masked_op.masked_func(remove_storm_motion, masked_array, wind, speed, dgi_dd_rotation_angle, dgi_dd_elevation_angle, boundary_masks = boundary_masks)
+    return masked_op.masked_func(remove_storm_motion_ray, masked_array, wind, speed, dgi_dd_rotation_angle, dgi_dd_elevation_angle, boundary_masks = boundary_masks)
